@@ -7,7 +7,7 @@
 //! pipeline):
 //!
 //! ```
-//! # #![feature(const_fn, const_loop, const_if_match, const_ptr_offset_from, const_transmute, ptr_offset_from)]
+//! # #![feature(const_ptr_offset_from)]
 //! # use web_glitz::runtime::RenderingContext;
 //! # fn wrapper<Rc>(context: &Rc) where Rc: RenderingContext {
 //! use web_glitz::buffer::UsageHint;
@@ -37,7 +37,7 @@
 //! of [Vertex] values:
 //!
 //! ```
-//! # #![feature(const_fn, const_transmute, const_ptr_offset_from, ptr_offset_from)]
+//! # #![feature(const_ptr_offset_from, const_fn_trait_bound)]
 //! # use web_glitz::runtime::RenderingContext;
 //! # fn wrapper<Rc>(context: &Rc) where Rc: RenderingContext {
 //! use web_glitz::buffer::{Buffer, UsageHint};
@@ -247,7 +247,10 @@ where
     /// # Panics
     ///
     /// Panics when [source] belongs to a different context.
-    pub fn copy_from_command<S>(&self, source: S) -> CopyCommand<T> where S: CopyFrom<T> {
+    pub fn copy_from_command<S>(&self, source: S) -> CopyCommand<T>
+    where
+        S: CopyFrom<T>,
+    {
         source.command(self.into())
     }
 }
@@ -334,6 +337,67 @@ impl<T> Buffer<[T]> {
     {
         index.get_unchecked(self)
     }
+
+    /// Returns a [BufferViewMut] on an element or a sub-slice of the elements this [Buffer],
+    /// depending on the type of `index`.
+    ///
+    /// - If given a position, returns a view on the element at that position or `None` if out of
+    ///   bounds.
+    /// - If given a range, returns a view on the sub-slice of elements corresponding to that range,
+    ///   or `None` if out of bounds.
+    ///
+    /// # Examples
+    ///
+    /// ```rust
+    /// # use web_glitz::runtime::RenderingContext;
+    /// # fn wrapper<Rc>(context: &Rc) where Rc: RenderingContext + Clone + 'static {
+    /// use web_glitz::buffer::{Buffer, BufferViewMut, UsageHint};
+    ///
+    /// let mut buffer: Buffer<[f32]> = context.create_buffer([1.0, 2.0, 3.0, 4.0], UsageHint::StreamDraw);
+    ///
+    /// buffer.get_mut(1); // Some BufferViewMut<f32> containing `2.0`
+    /// buffer.get_mut(1..3); // Some BufferViewMut<[f32]> containing `[2.0, 3.0]`
+    /// buffer.get_mut(..2); // Some BufferViewMut<[f32]> containing `[1.0 2.0]`
+    /// buffer.get_mut(4); // None (index out of bounds)
+    /// # }
+    /// ```
+    pub fn get_mut<I>(&mut self, index: I) -> Option<BufferViewMut<I::Output>>
+    where
+        I: BufferSliceIndex<T>,
+    {
+        index.get_mut(self)
+    }
+
+    /// Returns a [BufferViewMut] on an element or a sub-slice of the elements this [Buffer],
+    /// depending on the type of `index`, without doing bounds checking.
+    ///
+    /// - If given a position, returns a view on the element at that position, without doing bounds
+    ///   checking.
+    /// - If given a range, returns a view on the slice of elements corresponding to that range,
+    ///   without doing bounds checking.
+    ///
+    /// # Examples
+    ///
+    /// ```rust
+    /// # use web_glitz::runtime::RenderingContext;
+    /// # fn wrapper<Rc>(context: &Rc) where Rc: RenderingContext + Clone + 'static {
+    /// use web_glitz::buffer::{Buffer, BufferViewMut, UsageHint};
+    ///
+    /// let mut buffer: Buffer<[f32]> = context.create_buffer([1.0, 2.0, 3.0, 4.0], UsageHint::StreamDraw);
+    ///
+    /// unsafe { buffer.get_unchecked_mut(1) }; // BufferViewMut<f32> containing `2.0`
+    /// # }
+    /// ```
+    ///
+    /// # Unsafe
+    ///
+    /// Only safe if `index` is in bounds. See [get_mut] for a safe alternative.
+    pub unsafe fn get_unchecked_mut<I>(&mut self, index: I) -> BufferViewMut<I::Output>
+    where
+        I: BufferSliceIndex<T>,
+    {
+        index.get_unchecked_mut(self)
+    }
 }
 
 impl<T> Buffer<[T]>
@@ -384,7 +448,10 @@ where
     /// Panics when [source] belongs to a different context.
     ///
     /// Panics when [source] does not have the same length.
-    pub fn copy_from_command<S>(&self, source: S) -> CopyCommand<[T]> where S: CopyFrom<[T]> {
+    pub fn copy_from_command<S>(&self, source: S) -> CopyCommand<[T]>
+    where
+        S: CopyFrom<[T]>,
+    {
         source.command(self.into())
     }
 }
@@ -590,7 +657,10 @@ where
     /// # Panics
     ///
     /// Panics when [source] belongs to a different context.
-    pub fn copy_from_command<S>(&self, source: S) -> CopyCommand<T> where S: CopyFrom<T> {
+    pub fn copy_from_command<S>(&self, source: S) -> CopyCommand<T>
+    where
+        S: CopyFrom<T>,
+    {
         source.command(*self)
     }
 }
@@ -750,7 +820,10 @@ where
     /// Panics when [source] belongs to a different context.
     ///
     /// Panics when [source] does not have the same length.
-    pub fn copy_from_command<S>(&self, source: S) -> CopyCommand<[T]> where S: CopyFrom<[T]> {
+    pub fn copy_from_command<S>(&self, source: S) -> CopyCommand<[T]>
+    where
+        S: CopyFrom<[T]>,
+    {
         source.command(*self)
     }
 }
@@ -1348,7 +1421,10 @@ impl<T> BufferViewMutSliceIndex<T> for RangeToInclusive<usize> {}
 
 /// Helper trait for [Buffer::copy_from_command] and [BufferView::copy_from_command], implemented
 /// for types that can be copied from.
-pub trait CopyFrom<T> where T: ?Sized {
+pub trait CopyFrom<T>
+where
+    T: ?Sized,
+{
     fn command(self, target_view: BufferView<T>) -> CopyCommand<T>;
 }
 
@@ -1364,7 +1440,7 @@ impl<'a, T> CopyFrom<T> for &'a Buffer<T> {
             target_offset_in_bytes: target_view.offset_in_bytes(),
             source_offset_in_bytes: 0,
             size_in_bytes: mem::size_of::<T>(),
-            _marker: marker::PhantomData
+            _marker: marker::PhantomData,
         }
     }
 }
@@ -1381,7 +1457,7 @@ impl<'a, T> CopyFrom<T> for BufferView<'a, T> {
             target_offset_in_bytes: target_view.offset_in_bytes(),
             source_offset_in_bytes: self.offset_in_bytes(),
             size_in_bytes: mem::size_of::<T>(),
-            _marker: marker::PhantomData
+            _marker: marker::PhantomData,
         }
     }
 }
@@ -1402,7 +1478,7 @@ impl<'a, T> CopyFrom<[T]> for &'a Buffer<[T]> {
             target_offset_in_bytes: target_view.offset_in_bytes(),
             source_offset_in_bytes: 0,
             size_in_bytes: mem::size_of::<T>() * self.len(),
-            _marker: marker::PhantomData
+            _marker: marker::PhantomData,
         }
     }
 }
@@ -1423,7 +1499,7 @@ impl<'a, T> CopyFrom<[T]> for BufferView<'a, [T]> {
             target_offset_in_bytes: target_view.offset_in_bytes(),
             source_offset_in_bytes: self.offset_in_bytes(),
             size_in_bytes: self.size_in_bytes(),
-            _marker: marker::PhantomData
+            _marker: marker::PhantomData,
         }
     }
 }
@@ -1713,16 +1789,22 @@ unsafe impl<T> GpuTask<Connection> for DownloadCommand<[T]> {
 /// Command for copying data from one buffer to another.
 ///
 /// See [Buffer::copy_from_command] and [BufferView::copy_from_command] for details.
-pub struct CopyCommand<T> where T: ?Sized {
+pub struct CopyCommand<T>
+where
+    T: ?Sized,
+{
     target: Arc<BufferData>,
     source: Arc<BufferData>,
     target_offset_in_bytes: usize,
     source_offset_in_bytes: usize,
     size_in_bytes: usize,
-    _marker: marker::PhantomData<T>
+    _marker: marker::PhantomData<T>,
 }
 
-unsafe impl<T> GpuTask<Connection> for CopyCommand<T> where T: ?Sized {
+unsafe impl<T> GpuTask<Connection> for CopyCommand<T>
+where
+    T: ?Sized,
+{
     type Output = ();
 
     fn context_id(&self) -> ContextId {
@@ -1759,7 +1841,7 @@ unsafe impl<T> GpuTask<Connection> for CopyCommand<T> where T: ?Sized {
             GL::COPY_WRITE_BUFFER,
             self.source_offset_in_bytes as i32,
             self.target_offset_in_bytes as i32,
-            self.size_in_bytes as i32
+            self.size_in_bytes as i32,
         );
 
         Progress::Finished(())
