@@ -430,12 +430,9 @@ impl StencilOperation {
 ///     fail_operation_back: StencilOperation::Keep,
 ///     pass_depth_fail_operation_back: StencilOperation::Keep,
 ///     pass_operation_back: StencilOperation::Keep,
-///     reference_value_front: 0,
-///     test_mask_front: 0xffffffff,
-///     reference_value_back: 0,
-///     test_mask_back: 0xffffffff,
-///     write_mask_front: 0xffffffff,
-///     write_mask_back: 0xffffffff,
+///     reference_value: 0,
+///     test_mask: 0xffffffff,
+///     write_mask: 0xffffffff,
 /// });
 /// ```
 #[derive(PartialEq, Clone, Debug)]
@@ -504,52 +501,27 @@ pub struct StencilTest {
     /// instead.
     pub pass_operation_back: StencilOperation,
 
-    /// The value that is compared to a front-facing fragment's stencil value in the stencil buffer,
-    /// in order to decide if the fragment passes the stencil test.
+    /// The value that is compared to a fragment's stencil value in the stencil buffer, in order to
+    /// decide if the fragment passes the stencil test.
     ///
     /// See the type documentation for [StencilTest] for details on how this value is used when
     /// stencil testing.
-    pub reference_value_front: u32,
+    pub reference_value: u32,
 
-    /// The bitmask that is applied to both the [reference_value_front] and the stencil value in the
-    /// stencil buffer to which it is compared, before the stencil test is evaluated on a
-    /// front-facing fragment.
+    /// The bitmask that is applied to both the [reference_value] and the stencil value in the
+    /// stencil buffer to which it is compared, before the stencil test is evaluated on a fragment.
     ///
     /// Can be used to mask off certain bits, reserving them for different conditional tests.
     ///
     /// See the type documentation for [StencilTest] for details on how the [test_mask] is applied.
-    pub test_mask_front: u32,
-
-    /// The value that is compared to a back-facing fragment's stencil value in the stencil buffer,
-    /// in order to decide if the fragment passes the stencil test.
-    ///
-    /// See the type documentation for [StencilTest] for details on how this value is used when
-    /// stencil testing.
-    pub reference_value_back: u32,
-
-    /// The bitmask that is applied to both the [reference_value_back] and the stencil value in the
-    /// stencil buffer to which it is compared, before the stencil test is evaluated on a
-    /// back-facing fragment.
-    ///
-    /// Can be used to mask off certain bits, reserving them for different conditional tests.
-    ///
-    /// See the type documentation for [StencilTest] for details on how the [test_mask_back] is
-    /// applied.
-    pub test_mask_back: u32,
+    pub test_mask: u32,
 
     /// The bitmask that controls which of a stencil value's individual bits may be updated in the
-    /// stencil buffer when testing a front-facing fragment.
+    /// stencil buffer when testing a fragment.
     ///
     /// Suppose an 8-bit stencil buffer and a [write_mask] of `0000011`, then only the final two
     /// bits will be updated; where `0` appears, the bits are write-protected.
-    pub write_mask_front: u32,
-
-    /// The bitmask that controls which of a stencil value's individual bits may be updated in the
-    /// stencil buffer when testing a back-facing fragment.
-    ///
-    /// Suppose an 8-bit stencil buffer and a [write_mask] of `0000011`, then only the final two
-    /// bits will be updated; where `0` appears, the bits are write-protected.
-    pub write_mask_back: u32,
+    pub write_mask: u32,
 }
 
 impl StencilTest {
@@ -563,8 +535,8 @@ impl StencilTest {
                 state
                     .set_stencil_func_front(
                         stencil_test.test_function_front,
-                        stencil_test.reference_value_front as i32,
-                        stencil_test.test_mask_front,
+                        stencil_test.reference_value as i32,
+                        stencil_test.test_mask,
                     )
                     .apply(gl)
                     .unwrap();
@@ -579,15 +551,15 @@ impl StencilTest {
                     .unwrap();
 
                 state
-                    .set_stencil_write_mask_front(stencil_test.write_mask_front)
+                    .set_stencil_write_mask_front(stencil_test.write_mask)
                     .apply(gl)
                     .unwrap();
 
                 state
                     .set_stencil_func_back(
                         stencil_test.test_function_back,
-                        stencil_test.reference_value_back as i32,
-                        stencil_test.test_mask_back,
+                        stencil_test.reference_value as i32,
+                        stencil_test.test_mask,
                     )
                     .apply(gl)
                     .unwrap();
@@ -602,7 +574,7 @@ impl StencilTest {
                     .unwrap();
 
                 state
-                    .set_stencil_write_mask_back(stencil_test.write_mask_back)
+                    .set_stencil_write_mask_back(stencil_test.write_mask)
                     .apply(gl)
                     .unwrap();
             }
@@ -622,12 +594,9 @@ impl Default for StencilTest {
             fail_operation_back: StencilOperation::Keep,
             pass_depth_fail_operation_back: StencilOperation::Keep,
             pass_operation_back: StencilOperation::Keep,
-            reference_value_front: 0,
-            test_mask_front: 0xffffffff,
-            reference_value_back: 0,
-            test_mask_back: 0xffffffff,
-            write_mask_front: 0xffffffff,
-            write_mask_back: 0xffffffff,
+            reference_value: 0,
+            test_mask: 0xffffffff,
+            write_mask: 0xffffffff,
         }
     }
 }
