@@ -13,9 +13,9 @@ use crate::pipeline::graphics::shader::{FragmentShaderData, VertexShaderData};
 use crate::pipeline::graphics::util::BufferDescriptor;
 use crate::pipeline::graphics::{
     Blending, DepthTest, GraphicsPipelineDescriptor, PrimitiveAssembly, StencilTest,
-    TransformFeedbackBuffersEncodingContext, TransformFeedbackLayoutDescriptor,
-    TypedTransformFeedbackBuffers, TypedTransformFeedbackLayout, Untyped,
-    VertexInputLayoutDescriptor, Viewport,
+    TransformFeedbackBuffers, TransformFeedbackBuffersEncodingContext,
+    TransformFeedbackLayoutDescriptor, TypedTransformFeedbackBuffers, TypedTransformFeedbackLayout,
+    Untyped, VertexInputLayoutDescriptor, Viewport,
 };
 use crate::pipeline::resources::resource_slot::{SlotBindingUpdater, SlotType};
 use crate::pipeline::resources::{
@@ -55,6 +55,7 @@ pub struct GraphicsPipeline<V, R, Tf> {
     blending: Option<Blending>,
     viewport: Viewport,
     pub(crate) transform_feedback_data: Arc<UnsafeCell<Option<TransformFeedbackData>>>,
+    next_transform_feedback_recording_id: u32,
 }
 
 impl<V, R, Tf> GraphicsPipeline<V, R, Tf> {
@@ -137,8 +138,42 @@ impl<V, R, Tf> GraphicsPipeline<V, R, Tf> {
         Tf: TypedTransformFeedbackLayout,
         Fb: TypedTransformFeedbackBuffers<Layout = Tf>,
     {
+        let recording_id = self.next_transform_feedback_recording_id;
+
+        self.next_transform_feedback_recording_id += 1;
+
         RecordTransformFeedback {
             pipeline: self,
+            recording_id,
+            buffers: transform_feedback_buffers
+                .encode(&mut TransformFeedbackBuffersEncodingContext::new())
+                .into_descriptors(),
+            _marker: marker::PhantomData,
+        }
+    }
+
+    /// Returns a wrapped representation of this graphics pipeline that will record the output of
+    /// the vertex transformation stage(s) for the pipeline in the attached
+    /// `transform_feedback_buffers`.
+    ///
+    /// # Unsafe
+    ///
+    /// The transform feedback layout of the pipeline must be compatible with the layout of the
+    /// buffers.
+    pub unsafe fn record_transform_feedback_untyped<Fb>(
+        &mut self,
+        transform_feedback_buffers: Fb,
+    ) -> RecordTransformFeedback<V, R, Tf, Fb>
+    where
+        Fb: TransformFeedbackBuffers,
+    {
+        let recording_id = self.next_transform_feedback_recording_id;
+
+        self.next_transform_feedback_recording_id += 1;
+
+        RecordTransformFeedback {
+            pipeline: self,
+            recording_id,
             buffers: transform_feedback_buffers
                 .encode(&mut TransformFeedbackBuffersEncodingContext::new())
                 .into_descriptors(),
@@ -396,6 +431,7 @@ impl<V, R, Tf> GraphicsPipeline<V, R, Tf> {
             blending: descriptor.blending.clone(),
             viewport: descriptor.viewport.clone(),
             transform_feedback_data: Arc::new(UnsafeCell::new(None)),
+            next_transform_feedback_recording_id: 0,
         })
     }
 }
@@ -414,6 +450,7 @@ impl<V, R, Tf> Hash for GraphicsPipeline<V, R, Tf> {
 
 pub struct RecordTransformFeedback<'a, V, R, Tf, Fb> {
     pub(crate) pipeline: &'a mut GraphicsPipeline<V, R, Tf>,
+    pub(crate) recording_id: u32,
     pub(crate) buffers: StaticVec<BufferDescriptor, 16>,
     _marker: marker::PhantomData<Fb>,
 }
@@ -421,6 +458,7 @@ pub struct RecordTransformFeedback<'a, V, R, Tf, Fb> {
 pub(crate) struct TransformFeedbackData {
     pub(crate) id: JsId,
     pub(crate) state: TransformFeedbackState,
+    pub(crate) recording_id: u32,
     pub(crate) buffers: StaticVec<BufferDescriptor, 16>,
 }
 
